@@ -162,6 +162,9 @@ class Table:
     table_writer: Optional[Application] = None
     resource_reports: Optional[List[ResourceReport]] = None
     last_updated_timestamp: Optional[int] = None
+    last_successful_run_timestamp: Optional[int] = None
+    last_run_timestamp: Optional[int] = None
+    last_run_state: Optional[str] = None
     source: Optional[Source] = None
     is_view: Optional[bool] = attr.ib(default=None, converter=default_if_none)
     programmatic_descriptions: List[ProgrammaticDescription] = []
